<?php
/**
 * Portfolio and Projects Pro Shortcode Mapper Page
 *
 * @package Portfolio and Projects Pro
 * @since 1.2
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

$registered_shortcodes 	= wp_pap_registered_shortcodes();
$preview_shortcode 		= !empty($_GET['shortcode']) ? $_GET['shortcode'] : apply_filters('wp_pap_default_shortcode_preview', 'pap_portfolio' );
$preview_url 			= add_query_arg( array( 'page' => 'wp-pap-preview', 'shortcode' => $preview_shortcode), admin_url('admin.php') );
$shrt_generator_url 	= add_query_arg( array('post_type' => WP_PAP_PRO_POST_TYPE, 'page' => 'wp-pap-shrt-mapper'), admin_url('edit.php') );

// Instantiate the shortcode mapper
if( ! class_exists( 'Wp_Pap_Shortcode_Mapper' ) ) {
	include_once( WP_PAP_PRO_DIR . '/includes/admin/shortcode-mapper/class-wp-pap-shortcode-mapper.php' );
}

$shortcode_fields 	= array();
$shortcode_sanitize = str_replace('-', '_', $preview_shortcode);
?>
<div class="wrap wp-pap-customizer-settings">

	<h2><?php _e( 'Portfolio and Projects Pro - Shortcode Builder', 'portfolio-and-projects' ); ?></h2>

	<?php
	// If invalid shortocde is passed then simply return
	if( !empty($_GET['shortcode']) && !isset( $registered_shortcodes[ $_GET['shortcode'] ] ) ) {
		echo '<div id="message" class="error notice">
				<p><strong>'.__('Sorry, Something happened wrong.', 'portfolio-and-projects').'</strong></p>
			 </div>';
		return;
	}
	?>

	<div class="wp-pap-customizer-toolbar">
		<?php if( !empty( $registered_shortcodes ) ) { ?>
			<select class="wp-pap-cust-shrt-switcher" id="wp-pap-cust-shrt-switcher">
				<option value=""><?php _e('-- Choose Shortcode --', 'portfolio-and-projects'); ?></option>
				<?php foreach ($registered_shortcodes as $shrt_key => $shrt_val) {

					if( empty($shrt_key) ) {
						continue;
					}

					$shrt_val 		= !empty($shrt_val) ? $shrt_val : $shrt_key;
					$shortcode_url 	= add_query_arg( array('shortcode' => $shrt_key), $shrt_generator_url );
				?>
				<option value="<?php echo $shrt_key; ?>" <?php selected( $preview_shortcode, $shrt_key); ?> data-url="<?php echo esc_url( $shortcode_url ); ?>"><?php echo $shrt_val; ?></option>
				<?php } ?>
			</select>
		<?php } ?>
		<span class="wp-pap-cust-shrt-generate-help wp-pap-tooltip" title="<?php _e("The Shortcode Mapper allows you to preview plugin shortcode. You can choose your desired shortcode from the dropdown and check various parameters from left panel. \n\nYou can paste shortocde to below and press Generate button to preview so each and every time you do not have to choose each parameters!!!", 'portfolio-and-projects'); ?>"><i class="dashicons dashicons-editor-help"></i></span>
	</div><!-- end .wp-pap-customizer-toolbar -->

	<div class="wp-pap-customizer wp-pap-clearfix" data-shortcode="<?php echo $preview_shortcode; ?>">
		<div class="wp-pap-customizer-control wp-pap-clearfix">
			<div class="wp-pap-customizer-heading"><?php _e('Shortcode Parameters', 'portfolio-and-projects'); ?></div>
			<?php
				if ( function_exists( $shortcode_sanitize.'_shortcode_fields' ) ) {
					$shortcode_fields = call_user_func( $shortcode_sanitize.'_shortcode_fields', $preview_shortcode );
				}
				$shortcode_fields = apply_filters('wp_pap_shortcode_mapper_fields', $shortcode_fields, $preview_shortcode );

				$shortcode_mapper = new Wp_Pap_Shortcode_Mapper();
				$shortcode_mapper->render( $shortcode_fields );
			?>
		</div>

		<div class="wp-pap-customizer-preview wp-pap-clearfix">
			<div class="wp-pap-customizer-shrt-wrp">
				<div class="wp-pap-customizer-heading"><?php _e('Shortcode', 'portfolio-and-projects'); ?> 
					<div class="wp-pap-customizer-shrt-tool">
						<button type="button" class="button button-primary button-small wp-pap-cust-shrt-generate"><?php _e('Generate', 'portfolio-and-projects') ?></button>
						<i title="<?php _e('Full Preview Mode', 'portfolio-and-projects'); ?>" class="wp-pap-tooltip wp-pap-cust-dwp dashicons dashicons-editor-expand"></i>
					</div>
				</div>
				<form action="<?php echo esc_url($preview_url); ?>" method="post" class="wp-pap-customizer-shrt-form" id="wp-pap-customizer-shrt-form" target="wp_pap_customizer_preview_frame">
					<textarea name="wp_pap_customizer_shrt" class="wp-pap-customizer-shrt" id="wp-pap-customizer-shrt" placeholder="<?php _e('Copy or Paste Shortcode', 'portfolio-and-projects'); ?>"></textarea>
				</form>
			</div>
			<div class="wp-pap-customizer-heading"><?php _e('Preview Window', 'portfolio-and-projects'); ?> <span class="wp-pap-cust-heading-info wp-pap-tooltip" title="<?php _e('Preview will be displayed according to responsive layout mode. You can check with `Full Preview` mode for better visualization.', 'portfolio-and-projects'); ?>">[?]</span></div>
			<div class="wp-pap-customizer-window">
				<iframe class="wp-pap-customizer-preview-frame" name="wp_pap_customizer_preview_frame" src="<?php echo esc_url($preview_url); ?>" scrolling="auto" frameborder="0"></iframe>
				<div class="wp-pap-customizer-loader"></div>
				<div class="wp-pap-customizer-error"><?php _e('Sorry, Something happened wrong.', 'portfolio-and-projects'); ?></div>
			</div>
		</div>
	</div><!-- wp-pap-customizer -->

	<br/>
	<div class="wp-pap-cust-footer-note"><span class="description"><?php _e('Note: Preview will be displayed according to responsive layout mode. Live preview may display differently when added to your page based on inheritance from some styles.', 'portfolio-and-projects'); ?></span></div>

</div><!-- end .wrap -->