<?php
/**
 * Visual Composer Class
 *
 * Handles the visual composer shortcode functionality of plugin
 *
 * @package Portfolio and Projects Pro
 * @since 1.2
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

class Wp_Pap_Vc {

	function __construct() {

		// Action to add 'pap_portfolio' shortcode in vc
		add_action( 'vc_before_init', array($this, 'wp_pap_integrate_portfolio_vc') );

		// Action to add 'pap_portfolio_filter' shortcode in vc
		add_action( 'vc_before_init', array($this, 'wp_pap_integrate_portfolio_filter_vc') );
	}

	/**
	 * Function to add 'pap_portfolio' shortcode in vc
	 * 
	 * @package Portfolio and Projects Pro
 	 * @since 1.2
	 */
	function wp_pap_integrate_portfolio_vc() {
		vc_map( array(
			'name' 			=> 'WPOS - '.__( 'Portfolio Grid', 'portfolio-and-projects' ),
			'base' 			=> 'pap_portfolio',
			'icon' 			=> 'icon-wpb-wp',
			'class' 		=> '',
			'category' 		=> __( 'Content', 'portfolio-and-projects'),
			'description' 	=> __( 'Display portfolio in grid view.', 'portfolio-and-projects' ),
			'params' 	=> array(
								// General settings
								array(
									'type' 			=> 'dropdown',
									'class' 		=> '',
									'heading' 		=> __( 'Design', 'portfolio-and-projects' ),
									'param_name' 	=> 'design',
									'value' 		=> array(
															__( 'Portfolio Design 1', 'portfolio-and-projects' )	=> 'design-1',
															__( 'Portfolio Design 2', 'portfolio-and-projects' ) 	=> 'design-2',
															__( 'Portfolio Design 3', 'portfolio-and-projects' ) 	=> 'design-3',
															__( 'Portfolio Design 4', 'portfolio-and-projects' ) 	=> 'design-4',
															__( 'Portfolio Design 5', 'portfolio-and-projects' ) 	=> 'design-5',
															__( 'Portfolio Design 6', 'portfolio-and-projects' ) 	=> 'design-6',
															__( 'Portfolio Design 7', 'portfolio-and-projects' ) 	=> 'design-7',
															__( 'Portfolio Design 8', 'portfolio-and-projects' ) 	=> 'design-8',
															__( 'Portfolio Design 9', 'portfolio-and-projects' ) 	=> 'design-9',
															__( 'Portfolio Design 10', 'portfolio-and-projects' )	=> 'design-10',
															__( 'Portfolio Design 11', 'portfolio-and-projects' )	=> 'design-11',
															__( 'Portfolio Design 12', 'portfolio-and-projects' )	=> 'design-12',
															__( 'Portfolio Design 13', 'portfolio-and-projects' )	=> 'design-13',
															__( 'Portfolio Design 14', 'portfolio-and-projects' )	=> 'design-14',
															__( 'Portfolio Design 15', 'portfolio-and-projects' )	=> 'design-15',
														),
									'description' 	=> __( 'Choose portfolio design.', 'portfolio-and-projects' ),
									'admin_label' 	=> true,
								),
								array(
									'type' 			=> 'dropdown',
									'class' 		=> '',
									'heading' 		=> __( 'Grid', 'portfolio-and-projects' ),
									'param_name' 	=> 'grid',
									'value' 		=> array(
														__( 'Grid 1', 'portfolio-and-projects' ) => '1',
														__( 'Grid 2', 'portfolio-and-projects' ) => '2',
														__( 'Grid 3', 'portfolio-and-projects' ) => '3',
														__( 'Grid 4', 'portfolio-and-projects' ) => '4',
													),
									'std'			=> 3,
									'description' 	=> __( 'Choose number of columns for portfolios.', 'portfolio-and-projects' ),
								),
								array(
									'type' 			=> 'dropdown',
									'class' 		=> '',
									'heading' 		=> __( 'Popup Style', 'portfolio-and-projects' ),
									'param_name' 	=> 'popup_style',
									'value' 		=> array(
															__( 'Inline', 'portfolio-and-projects' )	=> 'inline',
															__( 'Popup', 'portfolio-and-projects' )		=> 'popup',
															__( 'No Popup', 'portfolio-and-projects' )	=> 'none',
														),
									'description' 	=> __( 'Choose portfolio popup style.', 'portfolio-and-projects' )
								),
								array(
									'type' 			=> 'dropdown',
									'class' 		=> '',
									'heading' 		=> __( 'Link', 'portfolio-and-projects' ),
									'param_name' 	=> 'link',
									'value' 		=> array(
															__( 'True', 'portfolio-and-projects' )	=> 'true',
															__( 'False', 'portfolio-and-projects' )	=> 'false',
														),
									'description' 	=> __( 'Enable link on portfolio.', 'portfolio-and-projects' ),
								),
								array(
									'type' 			=> 'dropdown',
									'class' 		=> '',
									'heading' 		=> __( 'Link Behaviour', 'portfolio-and-projects' ),
									'param_name' 	=> 'link_target',
									'value' 		=> array(
															__( 'Same Window', 'portfolio-and-projects' )	=> 'self',
															__( 'New Window', 'portfolio-and-projects' )	=> 'blank',
														),
									'description' 	=> __( 'Choose link behaviour.', 'portfolio-and-projects' ),
									'dependency' 	=> array(
															'element' 	=> 'link',
															'value' 	=> array( 'true' ),
														),
								),
								array(
									'type' 			=> 'textfield',
									'class' 		=> '',
									'heading' 		=> __( 'Image Size', 'portfolio-and-projects' ),
									'param_name' 	=> 'image_size',
									'value' 		=> 'full',
									'description' 	=> __( 'Enter WordPress registered image size. e.g', 'portfolio-and-projects' ).' thumbnail, medium, large, full.',
								),
								array(
									'type' 			=> 'textfield',
									'class' 		=> '',
									'heading' 		=> __( 'Portfolio Height', 'portfolio-and-projects' ),
									'param_name' 	=> 'portfolio_height',
									'value' 		=> '',
									'description' 	=> __( 'Enter portfolio box height. e.g 400. Leave empty for default.', 'portfolio-and-projects' ),
								),
								array(
									'type' 			=> 'textfield',
									'class' 		=> '',
									'heading' 		=> __( 'Design Offset', 'portfolio-and-projects' ),
									'param_name' 	=> 'design_offset',
									'value' 		=> '',
									'description' 	=> __( 'Distance between two portfolios. e.g 5. Leave empty for default.', 'portfolio-and-projects' ),
								),
								array(
									'type' 			=> 'dropdown',
									'class' 		=> '',
									'heading' 		=> __( 'Image Fit', 'portfolio-and-projects' ),
									'param_name' 	=> 'image_fit',
									'value' 		=> array(
														__( 'True', 'portfolio-and-projects' ) 	=> 'true',
														__( 'False', 'portfolio-and-projects' ) => 'false',
													),
									'description' 	=> __( 'Fill the portfolio image in a whole container.', 'portfolio-and-projects' ),
								),
								array(
									'type' 			=> 'textfield',
									'class' 		=> '',
									'heading' 		=> __( 'Extra Class', 'portfolio-and-projects' ),
									'param_name' 	=> 'extra_class',
									'value' 		=> '',
									'description' 	=> __( 'Enter extra CSS class for design customization.', 'portfolio-and-projects' ) . '<label title="'.__('Note: Extra class added as parent so using extra class you customize your design.', 'portfolio-and-projects').'"> [?]</label>',
								),

								// Data Settings
								array(
									'type' 			=> 'textfield',
									'class' 		=> '',
									'heading' 		=> __( 'Total Items', 'portfolio-and-projects' ),
									'param_name' 	=> 'limit',
									'value' 		=> 20,
									'description' 	=> __( 'Enter number of portfolio to be displayed. Enter -1 to display all.', 'portfolio-and-projects'),
									'group' 		=> __( 'Data Settings', 'portfolio-and-projects' ),
								),
								array(
									'type' 			=> 'dropdown',
									'class' 		=> '',
									'heading' 		=> __( 'Post Order By', 'portfolio-and-projects' ),
									'param_name' 	=> 'orderby',
									'value' 		=> array(
														__( 'Post Date', 'portfolio-and-projects' )				=> 'date',
														__( 'Post ID', 'portfolio-and-projects' )				=> 'ID',
														__( 'Post Author', 'portfolio-and-projects' )			=> 'author',
														__( 'Post Title', 'portfolio-and-projects' ) 			=> 'title',
														__( 'Post Slug', 'portfolio-and-projects' )	 			=> 'name',
														__( 'Post Modified Date', 'portfolio-and-projects' ) 	=> 'modified',
														__( 'Random', 'portfolio-and-projects' ) 				=> 'rand',
														__( 'Menu Order', 'portfolio-and-projects' ) 			=> 'menu_order',
													),
									'description' 	=> __( 'Select order type.', 'portfolio-and-projects' ),
									'group' 		=> __( 'Data Settings', 'portfolio-and-projects' )
								),
								array(
									'type' 			=> 'dropdown',
									'class' 		=> '',
									'heading' 		=> __( 'Post Order', 'portfolio-and-projects' ),
									'param_name' 	=> 'order',
									'value' 		=> array(
														__( 'Descending', 'portfolio-and-projects' ) 	=> 'desc',
														__( 'Ascending', 'portfolio-and-projects' ) 	=> 'asc',
													),
									'description' 	=> __( 'Select sorting order.', 'portfolio-and-projects' ),
									'group' 		=> __( 'Data Settings', 'portfolio-and-projects' )
								),
								array(
									'type' 			=> 'textfield',
									'class' 		=> '',
									'heading' 		=> __( 'Display Specific Category', 'portfolio-and-projects' ),
									'param_name' 	=> 'category',
									'value' 		=> '',
									'description' 	=> __( 'Enter category id to display categories wise.', 'portfolio-and-projects' ) . '<label title="'.__('You can pass multiple ids with comma seperated. You can find id at relevant category listing page.', 'portfolio-and-projects').'"> [?]</label>',
									'group' 		=> __( 'Data Settings', 'portfolio-and-projects' ),
								),
								array(
									'type' 			=> 'dropdown',
									'class' 		=> '',
									'heading' 		=> __( 'Include Category Children', 'portfolio-and-projects' ),
									'param_name' 	=> 'include_cat_child',
									'value' 		=> array(
														__( 'True', 'portfolio-and-projects' ) 	=> 'true',
														__( 'False', 'portfolio-and-projects' ) => 'false',
													),
									'description' 	=> __( 'If you are using parent category then whether to display child category or not.', 'portfolio-and-projects' ),
									'group' 		=> __( 'Data Settings', 'portfolio-and-projects' ),
								),
								array(
									'type' 			=> 'textfield',
									'class' 		=> '',
									'heading' 		=> __( 'Exclude Category', 'portfolio-and-projects' ),
									'param_name' 	=> 'exclude_cat',
									'value' 		=> '',
									'description' 	=> __( 'Exclude post category. Works only if `Category` field is empty.', 'portfolio-and-projects' ) . '<label title="'.__('You can pass multiple ids with comma seperated. You can find id at relevant category listing page.', 'portfolio-and-projects').'"> [?]</label>',
									'group' 		=> __( 'Data Settings', 'portfolio-and-projects' ),
								),
								array(
									'type' 			=> 'textfield',
									'class' 		=> '',
									'heading' 		=> __( 'Display Specific Posts', 'portfolio-and-projects' ),
									'param_name' 	=> 'posts',
									'value' 		=> '',
									'description' 	=> __('Enter id of the post which you want to display.', 'portfolio-and-projects') . '<label title="'.__('You can pass multiple ids with comma seperated. You can find id at relevant post listing page.', 'portfolio-and-projects').'"> [?]</label>',
									'group' 		=> __( 'Data Settings', 'portfolio-and-projects' ),
								),
								array(
									'type' 			=> 'textfield',
									'class' 		=> '',
									'heading' 		=> __( 'Exclude Post', 'portfolio-and-projects' ),
									'param_name' 	=> 'exclude_post',
									'value' 		=> '',
									'description' 	=> __('Enter id of the post which you do not want to display.', 'portfolio-and-projects') . '<label title="'.__('You can pass multiple ids with comma seperated. You can find id at relevant post listing page.', 'portfolio-and-projects').'"> [?]</label>',
									'group' 		=> __( 'Data Settings', 'portfolio-and-projects' ),
								),
								array(
									'type' 			=> 'dropdown',
									'class' 		=> '',
									'heading' 		=> __( 'Pagination', 'portfolio-and-projects' ),
									'param_name' 	=> 'pagination',
									'value' 		=> array(
															__( 'True', 'portfolio-and-projects' ) 	=> 'true',
															__( 'False', 'portfolio-and-projects' ) => 'false',
														),
									'dependency'	=> array(
															'element' 				=> 'limit',
															'value_not_equal_to' 	=> array( '-1' ),
														),
									'description' 	=> __( 'Enable pagination.', 'portfolio-and-projects' ),
									'group' 		=> __( 'Data Settings', 'portfolio-and-projects' ),
								),
								array(
									'type' 			=> 'dropdown',
									'class' 		=> '',
									'heading' 		=> __( 'Pagination Type', 'portfolio-and-projects' ),
									'param_name' 	=> 'pagination_type',
									'value' 		=> array(
															__( 'Numeric', 'portfolio-and-projects' )		=> 'numeric',
															__( 'Prev - Next', 'portfolio-and-projects' )	=> 'prev-next',
														),
									'description' 	=> __( 'Choose pagination type.', 'portfolio-and-projects' ),
									'dependency' 	=> array(
														'element' 				=> 'pagination',
														'value_not_equal_to' 	=> array( 'false' ),
														),
									'group' 		=> __( 'Data Settings', 'portfolio-and-projects' ),
								),
								array(
									'type' 			=> 'textfield',
									'class' 		=> '',
									'heading' 		=> __( 'Query Offset', 'portfolio-and-projects' ),
									'param_name' 	=> 'query_offset',
									'value' 		=> '',
									'description' 	=> __( 'Exclude number of posts from starting.', 'portfolio-and-projects' ) . '<label title="'.__('e.g if you pass 5 then it will skip first five post. Note: Do not use limit=-1 and pagination=true with this.', 'portfolio-and-projects').'"> [?]</label>',
									'group' 		=> __( 'Data Settings', 'portfolio-and-projects' ),
								),
							)
		));
	}

	/**
	 * Function to add 'pap_portfolio_filter' shortcode in vc
	 * 
	 * @package Portfolio and Projects Pro
 	 * @since 1.2
	 */
	function wp_pap_integrate_portfolio_filter_vc() {
		vc_map( array(
			'name' 			=> 'WPOS - '.__( 'Portfolio Filter', 'portfolio-and-projects' ),
			'base' 			=> 'pap_portfolio_filter',
			'icon' 			=> 'icon-wpb-wp',
			'class' 		=> '',
			'category' 		=> __( 'Content', 'portfolio-and-projects'),
			'description' 	=> __( 'Display portfolio filter view.', 'portfolio-and-projects' ),
			'params' 	=> array(
								// General settings
								array(
									'type' 			=> 'dropdown',
									'class' 		=> '',
									'heading' 		=> __( 'Design', 'portfolio-and-projects' ),
									'param_name' 	=> 'design',
									'value' 		=> array(
															__( 'Portfolio Design 1', 'portfolio-and-projects' ) 	=> 'design-1',
															__( 'Portfolio Design 2', 'portfolio-and-projects' ) 	=> 'design-2',
															__( 'Portfolio Design 3', 'portfolio-and-projects' ) 	=> 'design-3',
															__( 'Portfolio Design 4', 'portfolio-and-projects' ) 	=> 'design-4',
															__( 'Portfolio Design 5', 'portfolio-and-projects' ) 	=> 'design-5',
															__( 'Portfolio Design 6', 'portfolio-and-projects' ) 	=> 'design-6',
															__( 'Portfolio Design 7', 'portfolio-and-projects' ) 	=> 'design-7',
															__( 'Portfolio Design 8', 'portfolio-and-projects' ) 	=> 'design-8',
															__( 'Portfolio Design 9', 'portfolio-and-projects' ) 	=> 'design-9',
															__( 'Portfolio Design 10', 'portfolio-and-projects' ) 	=> 'design-10',
															__( 'Portfolio Design 11', 'portfolio-and-projects' ) 	=> 'design-11',
															__( 'Portfolio Design 12', 'portfolio-and-projects' ) 	=> 'design-12',
															__( 'Portfolio Design 13', 'portfolio-and-projects' ) 	=> 'design-13',
															__( 'Portfolio Design 14', 'portfolio-and-projects' ) 	=> 'design-14',
															__( 'Portfolio Design 15', 'portfolio-and-projects' ) 	=> 'design-15',
														),
									'description' 	=> __( 'Choose portfolio design.', 'portfolio-and-projects' ),
									'admin_label' 	=> true,
								),
								array(
									'type' 			=> 'dropdown',
									'class' 		=> '',
									'heading' 		=> __( 'Grid', 'portfolio-and-projects' ),
									'param_name' 	=> 'grid',
									'value' 		=> array(
														__( 'Grid 1', 'portfolio-and-projects' ) => '1',
														__( 'Grid 2', 'portfolio-and-projects' ) => '2',
														__( 'Grid 3', 'portfolio-and-projects' ) => '3',
														__( 'Grid 4', 'portfolio-and-projects' ) => '4',
													),
									'std'			=> 3,
									'description' 	=> __( 'Choose number of columns for portfolios.', 'portfolio-and-projects' ),
								),
								array(
									'type' 			=> 'dropdown',
									'class' 		=> '',
									'heading' 		=> __( 'Popup Style', 'portfolio-and-projects' ),
									'param_name' 	=> 'popup_style',
									'value' 		=> array(
															__( 'Inline', 'portfolio-and-projects' ) 	=> 'inline',
															__( 'Popup', 'portfolio-and-projects' ) 	=> 'popup',
															__( 'No Popup', 'portfolio-and-projects' ) 	=> 'none',
														),
									'description' 	=> __( 'Choose portfolio popup style.', 'portfolio-and-projects' )
								),
								array(
									'type' 			=> 'dropdown',
									'class' 		=> '',
									'heading' 		=> __( 'Link', 'portfolio-and-projects' ),
									'param_name' 	=> 'link',
									'value' 		=> array(
															__( 'True', 'portfolio-and-projects' ) 	=> 'true',
															__( 'False', 'portfolio-and-projects' ) => 'false',
														),
									'description' 	=> __( 'Enable link on portfolio.', 'portfolio-and-projects' ),
									
								),
								array(
									'type' 			=> 'dropdown',
									'class' 		=> '',
									'heading' 		=> __( 'Link Behaviour', 'portfolio-and-projects' ),
									'param_name' 	=> 'link_target',
									'value' 		=> array(
															__( 'Same Window', 'portfolio-and-projects' ) 	=> 'self',
															__( 'New Window', 'portfolio-and-projects' ) 	=> 'blank',
														),
									'description' 	=> __( 'Choose link behaviour.', 'portfolio-and-projects' ),
									'dependency' 	=> array(
															'element' 	=> 'link',
															'value' 	=> array( 'true' ),
														),
								),
								array(
									'type' 			=> 'textfield',
									'class' 		=> '',
									'heading' 		=> __( 'All Filter Text', 'portfolio-and-projects' ),
									'param_name' 	=> 'all_filter_text',
									'value' 		=> __('All', 'portfolio-and-projects'),
									'description' 	=> __( 'Entet the text value for `All` filter tag.', 'portfolio-and-projects' ),
								),
								array(
									'type' 			=> 'textfield',
									'class' 		=> '',
									'heading' 		=> __( 'Active Category Filter', 'portfolio-and-projects' ),
									'param_name' 	=> 'active_filter',
									'value' 		=> 1,
									'description' 	=> __( 'Enter number to remain active / default category tab at initial stage.', 'portfolio-and-projects') . '<label title="'.__('e.g 2 for second number category. You can pass cat-{Your Cat ID} (cat-20) also.', 'portfolio-and-projects').'"> [?]</label>',
								),
								array(
									'type' 			=> 'textfield',
									'class' 		=> '',
									'heading' 		=> __( 'Image Size', 'portfolio-and-projects' ),
									'param_name' 	=> 'image_size',
									'value' 		=> 'full',
									'description' 	=> __( 'Enter WordPress registered image size. e.g', 'portfolio-and-projects' ).' thumbnail, medium, large, full.',
								),
								array(
									'type' 			=> 'textfield',
									'class' 		=> '',
									'heading' 		=> __( 'Portfolio Height', 'portfolio-and-projects' ),
									'param_name' 	=> 'portfolio_height',
									'value' 		=> '',
									'description' 	=> __( 'Enter portfolio box height. e.g 400. Leave empty for default.', 'portfolio-and-projects' ),
								),
								array(
									'type' 			=> 'textfield',
									'class' 		=> '',
									'heading' 		=> __( 'Design Offset', 'portfolio-and-projects' ),
									'param_name' 	=> 'design_offset',
									'value' 		=> '',
									'description' 	=> __( 'Distance between two portfolios. e.g 5. Leave empty for default.', 'portfolio-and-projects' ),
								),
								array(
									'type' 			=> 'dropdown',
									'class' 		=> '',
									'heading' 		=> __( 'Image Fit', 'portfolio-and-projects' ),
									'param_name' 	=> 'image_fit',
									'value' 		=> array(
														__( 'True', 'portfolio-and-projects' ) 	=> 'true',
														__( 'False', 'portfolio-and-projects' ) => 'false',
													),
									'description' 	=> __( 'Fill the portfolio image in a whole container.', 'portfolio-and-projects' ),
								),
								array(
									'type' 			=> 'textfield',
									'class' 		=> '',
									'heading' 		=> __( 'Extra Class', 'portfolio-and-projects' ),
									'param_name' 	=> 'extra_class',
									'value' 		=> '',
									'description' 	=> __( 'Enter extra CSS class for design customization.', 'portfolio-and-projects' ) . '<label title="'.__('Note: Extra class added as parent so using extra class you customize your design.', 'portfolio-and-projects').'"> [?]</label>',
								),
								
								// Data Settings
								array(
									'type' 			=> 'textfield',
									'class' 		=> '',
									'heading' 		=> __( 'Category Limit', 'portfolio-and-projects' ),
									'param_name' 	=> 'cat_limit',
									'value' 		=> '',
									'description' 	=> __( 'Display number of categories. Leave empty for default value.', 'portfolio-and-projects'),
									'group' 		=> __( 'Data Settings', 'portfolio-and-projects' ),
								),
								array(
									'type' 			=> 'dropdown',
									'class' 		=> '',
									'heading' 		=> __( 'Category OrderBy', 'portfolio-and-projects' ),
									'param_name' 	=> 'cat_orderby',
									'value' 		=> array(
														__( 'Category Name', 'portfolio-and-projects' )			=> 'name',
														__( 'Category Slug', 'portfolio-and-projects' ) 		=> 'slug',
														__( 'Category ID', 'portfolio-and-projects' )			=> 'id',
														__( 'Category Count', 'portfolio-and-projects' ) 		=> 'count',
														__( 'Category Term Group', 'portfolio-and-projects' )	=> 'term_group',
														__( 'None', 'portfolio-and-projects' ) 					=> 'none',
													),
									'description' 	=> __( 'Select Category order type.', 'portfolio-and-projects' ),
									'group' 		=> __( 'Data Settings', 'portfolio-and-projects' )
								),
								array(
									'type' 			=> 'dropdown',
									'class' 		=> '',
									'heading' 		=> __( 'Category Order', 'portfolio-and-projects' ),
									'param_name' 	=> 'cat_order',
									'value' 		=> array(
														__( 'Descending', 'portfolio-and-projects' ) 	=> 'desc',
														__( 'Ascending', 'portfolio-and-projects' ) 	=> 'asc',
													),
									'std'			=> 'asc',
									'description' 	=> __( 'Select category sorting order.', 'portfolio-and-projects' ),
									'group' 		=> __( 'Data Settings', 'portfolio-and-projects' )
								),
								array(
									'type' 			=> 'dropdown',
									'class' 		=> '',
									'heading' 		=> __( 'Post Order By', 'portfolio-and-projects' ),
									'param_name' 	=> 'orderby',
									'value' 		=> array(
														__( 'Post Date', 'portfolio-and-projects' ) 			=> 'date',
														__( 'Post ID', 'portfolio-and-projects' ) 				=> 'ID',
														__( 'Post Author', 'portfolio-and-projects' ) 			=> 'author',
														__( 'Post Title', 'portfolio-and-projects' ) 			=> 'title',
														__( 'Post Slug', 'portfolio-and-projects' )	 			=> 'name',
														__( 'Post Modified Date', 'portfolio-and-projects' ) 	=> 'modified',
														__( 'Random', 'portfolio-and-projects' ) 				=> 'rand',
														__( 'Menu Order', 'portfolio-and-projects' ) 			=> 'menu_order',
													),
									'description' 	=> __( 'Select order type.', 'portfolio-and-projects' ),
									'group' 		=> __( 'Data Settings', 'portfolio-and-projects' )
								),
								array(
									'type' 			=> 'dropdown',
									'class' 		=> '',
									'heading' 		=> __( 'Post Order', 'portfolio-and-projects' ),
									'param_name' 	=> 'order',
									'value' 		=> array(
														__( 'Descending', 'portfolio-and-projects' ) 	=> 'desc',
														__( 'Ascending', 'portfolio-and-projects' ) 	=> 'asc',
													),
									'description' 	=> __( 'Select sorting order.', 'portfolio-and-projects' ),
									'group' 		=> __( 'Data Settings', 'portfolio-and-projects' )
								),
								array(
									'type' 			=> 'textfield',
									'class' 		=> '',
									'heading' 		=> __( 'Display Specific Category', 'portfolio-and-projects' ),
									'param_name' 	=> 'category',
									'value' 		=> '',
									'description' 	=> __( 'Enter category id to display categories wise.', 'portfolio-and-projects' ) . '<label title="'.__('You can pass multiple ids with comma seperated. You can find id at relevant category listing page.', 'portfolio-and-projects').'"> [?]</label>',
									'group' 		=> __( 'Data Settings', 'portfolio-and-projects' ),
								),
								array(
									'type' 			=> 'dropdown',
									'class' 		=> '',
									'heading' 		=> __( 'Include Category Child', 'portfolio-and-projects' ),
									'param_name' 	=> 'include_cat_child',
									'value' 		=> array(
															__( 'True', 'portfolio-and-projects' ) 	=> 'true',
															__( 'False', 'portfolio-and-projects' ) => 'false',
														),
									'description' 	=> __( 'If you are using parent category then whether to display child category or not.', 'portfolio-and-projects' ),
									'group' 		=> __( 'Data Settings', 'portfolio-and-projects' ),
								),
								array(
									'type' 			=> 'textfield',
									'class' 		=> '',
									'heading' 		=> __( 'Exclude Category', 'portfolio-and-projects' ),
									'param_name' 	=> 'exclude_cat',
									'value' 		=> '',
									'description' 	=> __( 'Exclude post category. Works only if `Category` field is empty.', 'portfolio-and-projects' ) . '<label title="'.__('You can pass multiple ids with comma seperated. You can find id at relevant category listing page.', 'portfolio-and-projects').'"> [?]</label>',
									'group' 		=> __( 'Data Settings', 'portfolio-and-projects' ),
								),
							)
		));
	}
}

$wp_pap_vc = new Wp_Pap_Vc();