<?php
/**
 * Script Class
 *
 * Handles the script and style functionality of plugin
 *
 * @package Portfolio and Projects Pro
 * @since 1.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

class WP_Pap_Pro_Script{

	function __construct() {

		// Action to add style at front side
		add_action( 'wp_enqueue_scripts', array($this, 'wp_pap_pro_front_style') );

		// Action to add script at front side
		add_action( 'wp_enqueue_scripts', array($this, 'wp_pap_pro_front_script') );

		// Action to add script at admin side
		add_action( 'admin_enqueue_scripts', array($this, 'wp_pap_pro_admin_script_style') );
	}

	/**
	 * Function to add style at front side
	 * 
	 * @package Portfolio and Projects Pro
	 * @since 1.0
	 */
	function wp_pap_pro_front_style() {

		// Registring and enqueing slick css
		if( ! wp_style_is( 'wpos-slick-style', 'registered' ) ) {
			wp_register_style( 'wpos-slick-style', WP_PAP_PRO_URL.'assets/css/slick.css', array(), WP_PAP_PRO_VERSION );
		}

		// Registring and enqueing magnific css
		if( ! wp_style_is( 'wpos-magnific-style', 'registered' ) ) {
			wp_register_style( 'wpos-magnific-style', WP_PAP_PRO_URL.'assets/css/magnific-popup.css', array(), WP_PAP_PRO_VERSION );
		}

		// Registring and enqueing public css
		wp_register_style( 'wp-pap-public-css', WP_PAP_PRO_URL.'assets/css/wp-pap-public.min.css', array(), WP_PAP_PRO_VERSION );

		wp_enqueue_style( 'wpos-slick-style');
		wp_enqueue_style( 'wpos-magnific-style');
		wp_enqueue_style( 'wp-pap-public-css' );
	}

	/**
	 * Function to add script at front side
	 * 
	 * @package Portfolio and Projects Pro
	 * @since 1.0
	 */
	function wp_pap_pro_front_script() {

		// Registring slick slider script
		if( ! wp_script_is( 'wpos-slick-jquery', 'registered' ) ) {
			wp_register_script( 'wpos-slick-jquery', WP_PAP_PRO_URL. 'assets/js/slick.min.js', array('jquery'), WP_PAP_PRO_VERSION, true);
		}

		// Registring magnific popup script
		if( ! wp_script_is( 'wpos-magnific-script', 'registered' ) ) {
			wp_register_script( 'wpos-magnific-script', WP_PAP_PRO_URL.'assets/js/jquery.magnific-popup.min.js', array('jquery'), WP_PAP_PRO_VERSION, true );
		}

		// Registring portfolio script
		wp_register_script( 'wp-pap-portfolio-js', WP_PAP_PRO_URL.'assets/js/wp-pap-portfolio.min.js', array('jquery'), WP_PAP_PRO_VERSION, true );

		// Registring public script
		wp_register_script( 'wp-pap-public-js', WP_PAP_PRO_URL.'assets/js/wp-pap-public.min.js', array('jquery'), WP_PAP_PRO_VERSION, true );
		wp_localize_script( 'wp-pap-public-js', 'WpPap', array(
															'is_mobile' 		=>	(wp_is_mobile()) 			? 1 : 0,
															'is_old_browser'	=> 	wp_pap_pro_old_browser() 	? 1 : 0,
														));
	}

	/**
	 * Function to add script at admin side
	 * 
	 * @package Portfolio and Projects Pro
	 * @since 1.0
	 */
	function wp_pap_pro_admin_script_style( $hook ) {

		global $wp_version, $wp_query, $typenow, $post_type;

		$new_ui = $wp_version >= '3.5' ? '1' : '0'; // Check wordpress version for older scripts

		// If it is plugin screen
		if( $typenow == WP_PAP_PRO_POST_TYPE ) {

			/* Styles */
			// Registring admin script
			wp_register_style( 'wp-pap-admin-style', WP_PAP_PRO_URL.'assets/css/wp-pap-admin.css', array(), WP_PAP_PRO_VERSION );
			wp_enqueue_style( 'wp-pap-admin-style' );


			/* Scripts */
			// Registring post order script
			wp_register_script( 'wp-pap-pro-ordering', WP_PAP_PRO_URL . 'assets/js/wp-pap-pro-ordering.js', array( 'jquery-ui-sortable' ), WP_PAP_PRO_VERSION, true );

			// Registring shortcode builder script
			wp_register_script( 'wp-pap-shortcode-mapper', WP_PAP_PRO_URL.'assets/js/wp-pap-shrt-mapper.min.js', array('jquery'), WP_PAP_PRO_VERSION, true );
			wp_localize_script( 'wp-pap-shortcode-mapper', 'Wp_Pap_Shrt_Mapper', array(
																'shortocde_err' => __("Sorry, Something happened wrong. Kindly please be sure that you have choosen relevant shortocde from the dropdown.", 'portfolio-and-projects'),
															));

			// Registring admin script
			wp_register_script( 'wp-pap-admin-script', WP_PAP_PRO_URL.'assets/js/wp-pap-admin.js', array('jquery'), WP_PAP_PRO_VERSION, true );
			wp_localize_script( 'wp-pap-admin-script', 'WppapAdmin', array(
																	'new_ui' 				=>	$new_ui,
																	'img_edit_popup_text'	=> __('Edit Image in Popup', 'portfolio-and-projects'),
																	'attachment_edit_text'	=> __('Edit Image', 'portfolio-and-projects'),
																	'img_delete_text'		=> __('Remove Image', 'portfolio-and-projects'),
																	'all_img_delete_text'	=> __('Are you sure to remove all images from this gallery!', 'portfolio-and-projects'),
																));
		}

		// Post Add - Edit Screen
		if( $post_type == WP_PAP_PRO_POST_TYPE && ( $hook == 'post.php' || $hook == 'post-new.php' ) ) {

			// Enqueue required inbuilt sctipt
			wp_enqueue_script( 'jquery-ui-sortable' );

			wp_enqueue_script( 'wp-pap-admin-script' );
			wp_enqueue_media(); // For media uploader
		}

		// Slider sorting - only when sorting by menu order on the blog listing page
		if ( $post_type == WP_PAP_PRO_POST_TYPE && isset( $wp_query->query['orderby'] ) && $wp_query->query['orderby'] == 'menu_order title' ) {
			wp_enqueue_script( 'wp-pap-pro-ordering' );
		}

		// Shortcode Builder
		if( $hook == WP_PAP_PRO_POST_TYPE . '_page_wp-pap-shrt-mapper' ) {
			wp_enqueue_script( 'shortcode' );
			wp_enqueue_script( 'jquery-ui-accordion' );
			wp_enqueue_script( 'wp-pap-shortcode-mapper' );
		}
	}
}

$wp_pap_pro_script = new WP_Pap_Pro_Script();