<?php
/**
 * 'pap_portfolio_filter' - Portfolio Filter Shortcode
 * 
 * @package Portfolio and Projects Pro
 * @since 1.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

function wp_pap_pro_portfolio_filter_shortcode( $atts, $content = '') {

	// Shortcode Parameter
	$atts = shortcode_atts(array(
		'design' 				=> 'design-1',
		'taxonomy'				=> '',
		'grid' 					=> 3,
		'category' 				=> '',
		'order'					=> 'DESC',
		'orderby'				=> 'date',
		'popup_style' 			=> 'inline',
		'include_cat_child'		=> 'true',
		'exclude_cat'			=> array(),
		'link'					=> 'true',
		'link_target'			=> 'self',
		'image_size'			=> 'full',
		'design_offset' 		=> '',
		'portfolio_height'		=> '',
		'cat_limit'				=> 0,
		'cat_order'				=> 'asc',
		'cat_orderby'			=> 'name',
		'active_filter'			=> 1,
		'all_filter_text'		=> __('All', 'portfolio-and-projects'),
		'image_fit'				=> 'true',
		'rtl'					=> '',
		'extra_class'			=> '',
		'className'				=> '',
		'align'					=> '',
	), $atts, 'pap_portfolio_filter');

	$shortcode_designs 				= wp_pap_pro_slider_designs();
	$popup_style_design				= wp_pap_pro_popup_style();
	$atts['cat_limit']				= wp_pap_pro_clean_number( $atts['cat_limit'], 0 );
	$atts['main_grid'] 				= wp_pap_pro_clean_number( $atts['grid'], 3 );
	$atts['main_grid'] 				= ( $atts['main_grid'] <= 4 ) ? $atts['main_grid'] : 3;
	$atts['design'] 				= ( $atts['design'] && ( array_key_exists( trim($atts['design'] ), $shortcode_designs ) ) ) ? trim($atts['design']) : 'design-1';
	$atts['taxonomy']				= ! empty( $atts['taxonomy'] )							? $atts['taxonomy']						: WP_PAP_PRO_CAT;
	$atts['cat'] 					= ( !empty( $atts['category'] ) )						? explode(',',$atts['category']) 		: '';
	$atts['order'] 					= ( strtolower($atts['order'] ) == 'asc' ) 				? 'ASC' 								: 'DESC';
	$atts['orderby'] 				= !empty( $atts['orderby'] ) 							? $atts['orderby'] 						: 'date';
	$atts['include_cat_child']		= ( $atts['include_cat_child'] == 'false' ) 			? false 								: true;
	$atts['exclude_cat'] 			= !empty( $atts['exclude_cat'] )						? explode(',', $atts['exclude_cat']) 	: array();
	$atts['link'] 					= ( $atts['link'] == 'true' )							? 1										: 0;
	$atts['link_target'] 			= ( $atts['link_target'] == 'blank' ) 					? '_blank' 								: '_self';
	$atts['image_size']				= !empty( $atts['image_size'] )							? $atts['image_size']					: 'full';
	$atts['popup_style'] 			= ( $atts['popup_style'] && ( array_key_exists( trim( $atts['popup_style'] ), $popup_style_design ) ) ) ? trim($atts['popup_style']) : '';
	$atts['active_filter']			= !empty($atts['active_filter']) 						? trim( $atts['active_filter'] ) 		: 1;
	$atts['all_filter_text'] 		= !empty($atts['all_filter_text']) 						? trim( $atts['all_filter_text'] ) 		: false;
	$atts['cat_order'] 				= ( strtolower( $atts['cat_order'] ) == 'asc' ) 		? 'ASC' 								: 'DESC';
	$atts['cat_orderby']			= !empty( $atts['cat_orderby'] ) 						? $atts['cat_orderby'] 					: 'name';
	$atts['image_fit']				= ( $atts['image_fit'] == 'false' )						? 0 									: 1;
	$atts['design_offset']			= is_numeric( $atts['design_offset'] )					? $atts['design_offset']				: '';
	$atts['align']					= !empty( $atts['align'] )								? 'align'.$atts['align']				: '';
	$atts['extra_class']			= $atts['extra_class'] .' '. $atts['align'] .' '. $atts['className'];
	$atts['extra_class']			= wp_pap_pro_sanitize_html_classes( $atts['extra_class'] );
	$atts['grid'] 					= wp_pap_grid_column( $atts['grid'] );

	// Extract Shortcode Var
	extract($atts);

	// For RTL
	if( empty($rtl) && is_rtl() ) {
		$rtl = 1;
	} elseif ( $rtl == 'true' ) {
		$rtl = 1;
	} else {
		$rtl = 0;
	}

	// Height
	$portfolio_height_css = '';
	if( $portfolio_height == 'auto' ) {
		$portfolio_height_css = "height:auto;";
	} elseif ( $portfolio_height > 0 ) {
		$portfolio_height_css = " height:{$portfolio_height}px;";
	}

	// Shortcode file
	$design_file_path 	= WP_PAP_PRO_DIR . '/templates/' . $design . '.php';
	$design_file 		= ( file_exists( $design_file_path ) ) ? $design_file_path : '';
	$popup_file_path	= ( $popup_style ) ? WP_PAP_PRO_DIR . '/templates/popup/' . $popup_style . '-portfolio.php' : '';

	// Thumb conf
	$atts['thumb_conf'] = compact('main_grid');

	// Taking some variables
	$count 			= 1;
	$popup_html 	= '';
	$prefix			= WP_PAP_PRO_META_PREFIX;
	$dummy_cat		= array( 0 => $all_filter_text );
	$old_browser	= wp_pap_pro_old_browser();
	$atts['unique'] = wp_pap_pro_get_unique();

	$atts['main_wrp_cls'] 	= "wppap-thumbs wppap-portfolio-filter wppap-{$design} wppap-clearfix";
	$atts['main_wrp_cls'] 	.= $popup_style 	? " wppap-portfolio-{$popup_style}" : '';
	$atts['main_wrp_cls']	.= ( $old_browser ) ? ' wp-pap-old-browser' 	: '';
	$atts['main_wrp_cls']	.= ( $image_fit ) 	? ' wp-pap-image-fit' 		: '';

	$atts['wrapper_css'] 	= ( $design_offset >= 0 ) ? "padding:{$design_offset}px;" : '';
	$atts['wrapper_css']	.= $portfolio_height_css;

	// Required enqueue_script
	if( $popup_style == 'inline' ) {
		wp_enqueue_script('wp-pap-portfolio-js');
	} elseif ( $popup_style == 'popup' ) {
		wp_enqueue_script('wpos-magnific-script');
	}
	wp_enqueue_script('wpos-slick-jquery');
	wp_enqueue_script('wp-pap-public-js');

	// Taking some globals
	global $post;

	$atts['wppapterms'] = get_terms( array(
						'taxonomy' 		=> $taxonomy,
						'fields'		=> 'id=>name',
						'hide_empty' 	=> true,
						'number'		=> $cat_limit,
						'order'			=> $cat_order,
						'orderby'		=> $cat_orderby,
						'include'       => $cat,
						'exclude'       => $exclude_cat,
				)
	);

	// If category is there
	if( ! is_wp_error($atts['wppapterms']) && ! empty($atts['wppapterms']) ) {

		// Getting ids 
		$wppap_cats = array_keys( $atts['wppapterms'] );

		// Add dummy cat `All` at first position
		$atts['wppapterms']		= ( $all_filter_text ) ? ( $dummy_cat + $atts['wppapterms'] ) : $atts['wppapterms'];
		$atts['terms_count']	= count( $atts['wppapterms'] );

		// Query Parameter
		$args = array ( 
			'post_type' 			=> WP_PAP_PRO_POST_TYPE,
			'post_status' 			=> array( 'publish' ),
			'orderby' 				=> $orderby, 
			'order' 				=> $order,
			'posts_per_page' 		=> -1,
			'ignore_sticky_posts'	=> true,
		);

		// Category Parameter
		if( ! empty($wppap_cats) ) {

			$args['tax_query'] = array(
									array(
										'taxonomy' 			=> $taxonomy,
										'field' 			=> 'term_id',
										'terms' 			=> $wppap_cats,
										'include_children'	=> $include_cat_child,
									)
								);
		}

		// WP Query
		$query = new WP_Query($args);

		ob_start();

		// Loop start file
		wp_pap_pro_get_template( 'filter/loop-start.php', $atts );

		while ($query->have_posts()) : $query->the_post();

			$atts['unique'] 				= wp_pap_pro_get_unique();
			$atts['portfolio_img'] 			= wp_pap_pro_get_image_src( get_post_thumbnail_id($post->ID), $image_size );
			$atts['portfolio_post_title'] 	= get_the_title();
			$atts['portfolio_url'] 			= wp_pap_pro_get_post_link($post->ID);
			$atts['portfolio_link'] 		= ( $atts['portfolio_url'] && empty($popup_style) && $link ) ? $atts['portfolio_url'] : 'javascript:void(0);';
			$atts['portfolio_link_target']	= ( $atts['portfolio_url'] && $link_target == '_blank' && empty($popup_style) && $link ) ? '_blank' : '_self';
			$atts['portfolio_cat'] 			= wp_pap_pro_get_post_cats( $post->ID, $taxonomy );

			$terms 		= get_the_terms( $post->ID, $taxonomy );
			$usedcat	= array();

			if( ! is_wp_error( $terms ) && $terms ) {
				foreach ( $terms as $term ) {
					$usedcat[] = 'wppap-cat-'.$term->term_id;
				}
			}

			$data_category 			= !empty($usedcat) ? implode( ' ', $usedcat ) : false;
			$atts['wrapper_cls'] 	= "wppap-portfolio-wrp thum-list wppap-portfolio-active wppap-columns wppap-medium-{$grid} {$data_category}";
			$atts['wrapper_cls'] 	.= ( ! $atts['portfolio_img'] ) ? ' wppap-no-image' : '';
			$atts['wrapper_cls'] 	.= ( $count % $main_grid == 1 ) ? ' wppap-first' : '';

			// Include design file
			wp_pap_pro_get_template( "filter/{$design}.php", $atts, null, null, "designs/{$design}.php" );

			if( !empty( $popup_style ) ) {

				// Popup Variable
				$atts['gallery_imgs'] 		= get_post_meta( $post->ID, $prefix.'gallery_id', true );
				$atts['project_url'] 		= wp_pap_pro_get_post_link($post->ID);
				$atts['cate_name'] 			= wp_pap_pro_get_post_cats( $post->ID, $taxonomy );
				$atts['tag_name'] 			= wp_pap_pro_get_post_cats( $post->ID, WP_PAP_PRO_TAG );
				$atts['right_cnt_wrp_cls']	= !empty( $atts['gallery_imgs'] ) ? 'wppap-medium-6' : 'wppap-medium-12';

				// Slider meta variables
				$arrows 				= get_post_meta( $post->ID, $prefix.'arrow_slider', true );
				$dots 					= get_post_meta( $post->ID, $prefix.'pagination_slider', true );
				$effect 				= get_post_meta( $post->ID, $prefix.'animation_slider', true );
				$slide_to_show 			= get_post_meta( $post->ID, $prefix.'slide_to_show_slider', true );
				$loop 					= get_post_meta( $post->ID, $prefix.'loop_slider', true );
				$autoplay 				= get_post_meta( $post->ID, $prefix.'autoplay_slider', true );
				$autoplayspeed			= get_post_meta( $post->ID, $prefix.'autoplayspeed_slider', true );
				$speed 					= get_post_meta( $post->ID, $prefix.'speed_slider', true );

				// Slider configuration
				$atts['slider_conf'] = compact('dots', 'arrows', 'effect', 'slide_to_show', 'loop', 'autoplay', 'autoplayspeed', 'speed', 'rtl');

				// Creating Popup HTML
				$popup_html .= wp_pap_pro_get_template_html( "filter/{$popup_style}-portfolio.php", $atts, null, null, "popup/{$popup_style}-portfolio.php" );
			}

			$count++;
		endwhile;

		// Loop end file
		wp_pap_pro_get_template( 'filter/loop-end.php', $atts );
		
		echo $popup_html; // Printing popup html

		wp_reset_postdata(); // Reset WP Query

		$content .= ob_get_clean();
		return $content;

	} // End of category check
}

// Portfolio Filter Shortcode
add_shortcode( 'pap_portfolio_filter', 'wp_pap_pro_portfolio_filter_shortcode' );