<?php
/**
 * 'pap_portfolio' - Portfolio Grid Shortcode
 * 
 * @package Portfolio and Projects Pro
 * @since 1.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

function wp_pap_pro_portfolio_shortcode( $atts, $content = '') {

	// Taking some globals
	global $post, $multipage;

	// Shortcode Parameter
	$atts = shortcode_atts(array(
			'design' 				=> 'design-1',
			'taxonomy'				=> '',
			'grid' 					=> 3,
			'limit' 				=> 20,
			'category' 				=> '',
			'order'					=> 'DESC',
			'orderby'				=> 'date',
			'popup_style' 			=> 'inline',
			'include_cat_child'		=> 'true',
			'pagination' 			=> 'true',
			'pagination_type'		=> 'numeric',
			'posts'					=> array(),
			'exclude_cat'			=> array(),
			'exclude_post'			=> array(),
			'link'					=> 'true',
			'link_target'			=> 'self',
			'image_size'			=> 'full',
			'design_offset' 		=> '',
			'portfolio_height'		=> '',
			'image_fit'				=> 'true',
			'rtl'					=> '',
			'query_offset'			=> '',
			'extra_class'			=> '',
			'className'				=> '',
			'align'					=> '',
	), $atts, 'pap_portfolio');

	$shortcode_designs 				= wp_pap_pro_slider_designs();
	$popup_style_design				= wp_pap_pro_popup_style();
	$atts['posts_per_page'] 		= wp_pap_pro_clean_number( $atts['limit'], 20, 'number' );
	$atts['main_grid'] 				= wp_pap_pro_clean_number( $atts['grid'], 3 );
	$atts['main_grid'] 				= ( $atts['main_grid'] <= 4 ) ? $atts['main_grid'] : 3;
	$atts['design'] 				= ( $atts['design'] && ( array_key_exists( trim( $atts['design'] ), $shortcode_designs ) ) ) ? trim($atts['design']) : 'design-1';
	$atts['taxonomy']				= ( !empty( $atts['taxonomy'] ) )					? $atts['taxonomy']						: WP_PAP_PRO_CAT;
	$atts['cat'] 					= ( !empty( $atts['category'] ) )					? explode(',',$atts['category']) 		: '';
	$atts['order'] 					= ( strtolower( $atts['order'] ) == 'asc' ) 		? 'ASC' 								: 'DESC';
	$atts['orderby'] 				= !empty( $atts['orderby'] ) 						? $atts['orderby'] 						: 'date';
	$atts['include_cat_child']		= ( $atts['include_cat_child'] == 'false' ) 		? false 								: true;
	$atts['pagination'] 			= ( $atts['pagination'] == 'false' )				? 0										: 1;
	$atts['pagination_type'] 		= ( $atts['pagination_type'] == 'prev-next' )		? 'prev-next' 							: 'numeric';
	$atts['exclude_cat'] 			= !empty( $atts['exclude_cat'] )					? explode(',', $atts['exclude_cat']) 	: array();
	$atts['exclude_post'] 			= !empty( $atts['exclude_post'] )					? explode(',', $atts['exclude_post']) 	: array();
	$atts['posts'] 					= !empty( $atts['posts'] )							? explode(',', $atts['posts']) 			: array();
	$atts['link'] 					= ( $atts['link'] == 'true' )						? 1										: 0;
	$atts['link_target'] 			= ( $atts['link_target'] == 'blank' ) 				? '_blank' 								: '_self';
	$atts['image_size']				= ( !empty( $atts['image_size'] ) ) 				? $atts['image_size'] 					: 'full';
	$atts['design_offset']			= is_numeric( $atts['design_offset'] )				? $atts['design_offset']				: '';
	$atts['popup_style'] 			= ( $atts['popup_style'] && ( array_key_exists( trim( $atts['popup_style'] ), $popup_style_design ) ) ) ? trim($atts['popup_style']) : '';
	$atts['image_fit']				= ( $atts['image_fit'] == 'false' ) 				? 0 : 1;
	$atts['query_offset']			= !empty( $atts['query_offset'] )					? $atts['query_offset'] 				: null;
	$atts['align']					= !empty( $atts['align'] )							? 'align'.$atts['align']				: '';
	$atts['extra_class']			= $atts['extra_class'] .' '. $atts['align'] .' '. $atts['className'];
	$atts['extra_class']			= wp_pap_pro_sanitize_html_classes( $atts['extra_class'] );
	$atts['multi_page']				= ( $multipage || is_single() || is_front_page() ) ? 1 : 0;
	$atts['grid'] 					= wp_pap_grid_column( $atts['grid'] );

	// Extract Shortcode Var
	extract($atts);

	// For RTL
	if( empty( $rtl ) && is_rtl() ) {
		$rtl = 1;
	} elseif ( $rtl == 'true' ) {
		$rtl = 1;
	} else {
		$rtl = 0;
	}

	// Height
	$portfolio_height_css 	= '';
	if( $portfolio_height == 'auto' ) {
		$portfolio_height_css = "height:auto;";
	} elseif ( $portfolio_height > 0 ) {
		$portfolio_height_css = " height:{$portfolio_height}px;";
	}

	// Thumb conf
	$atts['thumb_conf'] = compact('main_grid');

	// Taking some variables
	$count 					= 1;
	$popup_html 			= '';
	$prefix					= WP_PAP_PRO_META_PREFIX;
	$old_browser			= wp_pap_pro_old_browser();
	$atts['unique']			= wp_pap_pro_get_unique();

	// Taking some variables
	$atts['main_wrp_cls'] 	= "wppap-thumbs wppap-{$design}";
	$atts['main_wrp_cls'] 	.= $popup_style 		? " wppap-portfolio-{$popup_style}" : '';
	$atts['main_wrp_cls']	.= ( $old_browser ) 	? ' wp-pap-old-browser' 	: '';
	$atts['main_wrp_cls']	.= ( $image_fit ) 		? ' wp-pap-image-fit' 		: '';

	$atts['wrapper_css'] 	= ( $design_offset >= 0 ) ? "padding:{$design_offset}px;" : '';
	$atts['wrapper_css']	.= $portfolio_height_css;

	// Required enqueue_script
	if( $popup_style == 'inline' ) {
		wp_enqueue_script('wp-pap-portfolio-js');
	} elseif ( $popup_style == 'popup' ) {
		wp_enqueue_script('wpos-magnific-script');
	}
	wp_enqueue_script('wpos-slick-jquery');
	wp_enqueue_script('wp-pap-public-js');

	// Pagination parameter
	$paged = 1;
	if( $multi_page ) {
		$paged = isset( $_GET['wppap_page'] ) ? $_GET['wppap_page'] : 1;
	} else if ( get_query_var('paged') ) {
		$paged = get_query_var('paged');
	} else if ( get_query_var('page') ) {
		$paged = get_query_var('page');
	}

	// Taking care of query offset with pagination
	if( $query_offset && $pagination && $paged > 1 ) {
		$offset = $query_offset + ( ($paged - 1) * $limit );
	} else {
		$offset = $query_offset;
	}

	// Query Parameter
	$args = array ( 
				'post_type' 			=> WP_PAP_PRO_POST_TYPE,
				'post_status' 			=> array( 'publish' ),
				'orderby' 				=> $orderby, 
				'order' 				=> $order,
				'posts_per_page' 		=> $posts_per_page,
				'paged' 				=> ( $pagination ) ? $paged : 1,
				'post__in'				=> $posts,
				'post__not_in'			=> $exclude_post,
				'offset'				=> $offset,
				'ignore_sticky_posts'	=> true,
			);

	// Category Parameter
	if( ! empty($cat) ) {

		$args['tax_query'] = array(
								array(
									'taxonomy' 			=> $taxonomy,
									'field' 			=> 'term_id',
									'terms' 			=> $cat,
									'include_children'	=> $include_cat_child,
								));

	} else if( !empty($exclude_cat) ) {
		
		$args['tax_query'] = array(
								array(
									'taxonomy' 			=> $taxonomy,
									'field' 			=> 'term_id',
									'terms' 			=> $exclude_cat,
									'operator'			=> 'NOT IN',
									'include_children'	=> $include_cat_child,
								));
	}

	// WP Query
	$query = new WP_Query($args);

	//Template Variable
	$atts['paged']			= $paged;
	$atts['max_num_pages']	= $query->max_num_pages;

	// Little tweak for pagination with query offset
	if ( $pagination && $query_offset ) {
		$found_posts			= ( $query->found_posts - $query_offset );
		$atts['max_num_pages']	= ceil( $found_posts / $limit );
	}

	ob_start();

		// Loop start file
		wp_pap_pro_get_template( 'grid/loop-start.php', $atts );

		while ($query->have_posts()) : $query->the_post();

			$atts['unique'] 				= wp_pap_pro_get_unique();
			$atts['portfolio_img'] 			= wp_pap_pro_get_image_src( get_post_thumbnail_id($post->ID), $image_size );
			$atts['portfolio_post_title'] 	= get_the_title();
			$atts['portfolio_url'] 			= wp_pap_pro_get_post_link($post->ID);
			$atts['portfolio_link'] 		= ( $atts['portfolio_url'] && empty( $popup_style ) && $link ) ? esc_url($atts['portfolio_url']) : '';
			$atts['portfolio_link_target']	= ( $atts['portfolio_url'] && $link_target == '_blank' && empty($popup_style) && $link ) ? '_blank' : '_self';
			$atts['wrapper_cls'] 			= "wppap-portfolio-wrp thum-list wppap-columns wppap-medium-{$grid}";
			$atts['wrapper_cls'] 			.= ( !$atts['portfolio_img'] ) ? ' wppap-no-image' : '';
			$atts['wrapper_cls'] 			.= ( $count % $main_grid == 1 ) ? ' wppap-first' : '';
			$atts['portfolio_cat'] 			= wp_pap_pro_get_post_cats( $post->ID, $taxonomy );

			// Include design file
			wp_pap_pro_get_template( "grid/{$design}.php", $atts, null, null, "designs/{$design}.php" );

			// If popup is there
			if( !empty( $popup_style ) ) {

				// Popup Variable
				$atts['gallery_imgs'] 		= get_post_meta( $post->ID, $prefix.'gallery_id', true );
				$atts['project_url'] 		= wp_pap_pro_get_post_link( $post->ID );
				$atts['cate_name'] 			= wp_pap_pro_get_post_cats( $post->ID, $taxonomy );
				$atts['tag_name'] 			= wp_pap_pro_get_post_cats( $post->ID, WP_PAP_PRO_TAG );
				$atts['right_cnt_wrp_cls']	= !empty( $atts['gallery_imgs'] ) ? 'wppap-medium-6' : 'wppap-medium-12';

				// Slider meta variables
				$arrows 		= get_post_meta( $post->ID, $prefix.'arrow_slider', true );
				$dots 			= get_post_meta( $post->ID, $prefix.'pagination_slider', true );
				$effect 		= get_post_meta( $post->ID, $prefix.'animation_slider', true );
				$slide_to_show 	= get_post_meta( $post->ID, $prefix.'slide_to_show_slider', true );
				$loop 			= get_post_meta( $post->ID, $prefix.'loop_slider', true );
				$autoplay 		= get_post_meta( $post->ID, $prefix.'autoplay_slider', true );
				$autoplayspeed	= get_post_meta( $post->ID, $prefix.'autoplayspeed_slider', true );
				$speed 			= get_post_meta( $post->ID, $prefix.'speed_slider', true );

				// Slider configuration
				$atts['slider_conf'] = compact('dots', 'arrows', 'effect', 'slide_to_show', 'loop', 'autoplay', 'autoplayspeed', 'speed', 'rtl');

				// Creating Popup HTML
				$popup_html .= wp_pap_pro_get_template_html( "grid/{$popup_style}-portfolio.php", $atts, null, null, "popup/{$popup_style}-portfolio.php" );
			}

			$count++;
		endwhile;

		// Loop end file
		wp_pap_pro_get_template( 'grid/loop-end.php', $atts );

		echo $popup_html; // Printing popup html

	wp_reset_postdata(); // Reset WP Query

	$content .= ob_get_clean();
	return $content;
}

// Portfolio Grid Shortcode
add_shortcode('pap_portfolio', 'wp_pap_pro_portfolio_shortcode');